@@ -28,8 +28,6 @@ namespace Client
 class PlasmaWindow;
 class PlasmaShell;
 class PlasmaShellSurface;
-class Shell;
-class ShellSurface;
 class Surface;
 }
 }
@@ -54,10 +52,8 @@ protected:
 private:
     void initWayland();
     KWayland::Client::PlasmaShellSurface *m_plasmaShellSurface = nullptr;
-    KWayland::Client::ShellSurface *m_shellSurface = nullptr;
     KWayland::Client::Surface *m_surface = nullptr;
     KWayland::Client::PlasmaShell *m_plasmaShellInterface = nullptr;
-    KWayland::Client::Shell *m_shellInterface = nullptr;
     bool m_acceptsFocus = true;
 };
 
